@@ -10,6 +10,8 @@ import json
 import os
 import time
 
+from .eventlog import EventLog
+
 
 class SparkReport(object):
     """Save time differences to a file
@@ -29,12 +31,17 @@ class SparkReport(object):
                 'parallelism': manager.defaultParallelism,
                 'executors': manager._jsc.sc().getExecutorMemoryStatus().size(),
             },
+            'app': {},
             'slurm': {
                 'jobid': os.environ.get('SLURM_JOBID', ''),
                 'nodes': os.environ.get('SLURM_NODELIST', ''),
             }
         }
         self.__start = time.time()
+        self.__eventlog = None
+        logdir = manager.getConf().get('spark.eventLog.dir')
+        if logdir:
+            self.__eventlog = os.path.join(logdir, manager.getConf().get('spark.app.id') + '.inprogress')
         if not os.path.exists(os.path.dirname(filename)):
             os.makedirs(os.path.dirname(filename))
         elif os.path.exists(filename):
@@ -48,10 +55,28 @@ class SparkReport(object):
             """
             now = time.time()
             self.__report['runtime'].append((now - self.__start, self.__start, now))
+            if os.path.exists(self.__eventlog):
+                try:
+                    log = EventLog(self.__eventlog)
+                    self.__report['spark']['shuffle'] = log.shuffle_size
+                    self.__report['spark']['rows_max'] = log.max_rows
+                    self.__report['spark']['rows_last'] = log.last_rows
+                except Exception as e:
+                    self.__report['spark']['processing_error'] = str(e)
+                    self.__report['spark']['shuffle'] = float('nan')
+                    self.__report['spark']['rows_max'] = float('nan')
+                    self.__report['spark']['rows_last'] = float('nan')
             with open(self.__filename, 'w') as fd:
                 json.dump(self.__report, fd)
         atexit.register(finish)
 
+    def add_info(self, data):
+        """Add additional information to the report
+
+        :param data: a dictionary to store under the key `app`
+        """
+        self.__report['app'].update(data)
+
     def __call__(self, name, start, end):
         """Update stored information
 
@@ -168,6 +193,14 @@ class SparkManager(object):
 
         return self.__session
 
+    def record(self, data):
+        """Pass application data through to the report (if enabled)
+
+        :param data: a dictionary to save in the report JSON
+        """
+        if self.__report:
+            self.__report.add_info(data)
+
     def register_java_functions(self, fcts):
         """Register java functions with the SQL context of Spark
 
